# Ubuntu Developer Summit web application
# Copyright (C) 2008, 2009, 2010 Canonical Ltd
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.core.exceptions import PermissionDenied
from django.contrib import admin
from django.shortcuts import render_to_response
from django.template import RequestContext
from django.utils.encoding import force_unicode
from django.utils.safestring import mark_safe
from django.utils.translation import ugettext as _

from summit.brainstorm.models import Idea

from summit.brainstorm.forms import IdeaForm

__all__ = (
)


class IdeaAdmin(admin.ModelAdmin):
    list_display = ('url', 'title')
    fieldsets = (
        (None, {
            'fields': ('id', 'title', 'url'),
        }),
    )

    add_form = IdeaForm

    def add_view(self, request):
        if not self.has_add_permission(request):
            raise PermissionDenied

        new_idea = None
        if request.method == 'POST':
            form = self.add_form(request.POST)
            if form.is_valid():
                # We're using the wrong field, so this is wrong
                new_idea = form.cleaned_data['idea']
                self.log_addition(request, new_idea)

                return self.response_add(request, new_idea)
        else:
            form = self.add_form()

        context = {
            'title': _('Add %s') % force_unicode(self.model._meta.verbose_name),
            'form': form,
            'is_popup': '_popup' in request.REQUEST,
            'add': True,
            'change': False,
            'has_add_permission': self.has_add_permission(request),
            'has_delete_permission': self.has_delete_permission(request, new_idea),
            'has_change_permission': self.has_change_permission(request, new_idea),
            'has_file_field': False,
            'has_absolute_url': False,
            'opts': self.model._meta,
            'save_as': False,
            'root_path': self.admin_site.root_path,
            'show_delete': False,
            'media': mark_safe(self.media + form.media),
            'app_label': self.model._meta.app_label,
        }
        return render_to_response('admin/brainstorm/idea/add_form.html',
                                  context,
                                  context_instance=RequestContext(request))

admin.site.register(Idea, IdeaAdmin)
